<?php

namespace Marwein\TestInlineTranslation\Tests\Unit\Domain\Model;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Test case for class \Marwein\TestInlineTranslation\Domain\Model\InlineTest.
 *
 * @copyright Copyright belongs to the respective authors
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class InlineTestTest extends \TYPO3\CMS\Core\Tests\UnitTestCase {
	/**
	 * @var \Marwein\TestInlineTranslation\Domain\Model\InlineTest
	 */
	protected $subject = NULL;

	protected function setUp() {
		$this->subject = new \Marwein\TestInlineTranslation\Domain\Model\InlineTest();
	}

	protected function tearDown() {
		unset($this->subject);
	}

	/**
	 * @test
	 */
	public function getTitleReturnsInitialValueForString() {
		$this->assertSame(
			'',
			$this->subject->getTitle()
		);
	}

	/**
	 * @test
	 */
	public function setTitleForStringSetsTitle() {
		$this->subject->setTitle('Conceived at T3CON10');

		$this->assertAttributeEquals(
			'Conceived at T3CON10',
			'title',
			$this->subject
		);
	}

	/**
	 * @test
	 */
	public function getFalPropertyReturnsInitialValueForFileReference() {
		$this->assertEquals(
			NULL,
			$this->subject->getFalProperty()
		);
	}

	/**
	 * @test
	 */
	public function setFalPropertyForFileReferenceSetsFalProperty() {
		$fileReferenceFixture = new \TYPO3\CMS\Extbase\Domain\Model\FileReference();
		$this->subject->setFalProperty($fileReferenceFixture);

		$this->assertAttributeEquals(
			$fileReferenceFixture,
			'falProperty',
			$this->subject
		);
	}

	/**
	 * @test
	 */
	public function getInlinePropertiesReturnsInitialValueForInlineProperty() {
		$newObjectStorage = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$this->assertEquals(
			$newObjectStorage,
			$this->subject->getInlineProperties()
		);
	}

	/**
	 * @test
	 */
	public function setInlinePropertiesForObjectStorageContainingInlinePropertySetsInlineProperties() {
		$inlineProperty = new \Marwein\TestInlineTranslation\Domain\Model\InlineProperty();
		$objectStorageHoldingExactlyOneInlineProperties = new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
		$objectStorageHoldingExactlyOneInlineProperties->attach($inlineProperty);
		$this->subject->setInlineProperties($objectStorageHoldingExactlyOneInlineProperties);

		$this->assertAttributeEquals(
			$objectStorageHoldingExactlyOneInlineProperties,
			'inlineProperties',
			$this->subject
		);
	}

	/**
	 * @test
	 */
	public function addInlinePropertyToObjectStorageHoldingInlineProperties() {
		$inlineProperty = new \Marwein\TestInlineTranslation\Domain\Model\InlineProperty();
		$inlinePropertiesObjectStorageMock = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array('attach'), array(), '', FALSE);
		$inlinePropertiesObjectStorageMock->expects($this->once())->method('attach')->with($this->equalTo($inlineProperty));
		$this->inject($this->subject, 'inlineProperties', $inlinePropertiesObjectStorageMock);

		$this->subject->addInlineProperty($inlineProperty);
	}

	/**
	 * @test
	 */
	public function removeInlinePropertyFromObjectStorageHoldingInlineProperties() {
		$inlineProperty = new \Marwein\TestInlineTranslation\Domain\Model\InlineProperty();
		$inlinePropertiesObjectStorageMock = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array('detach'), array(), '', FALSE);
		$inlinePropertiesObjectStorageMock->expects($this->once())->method('detach')->with($this->equalTo($inlineProperty));
		$this->inject($this->subject, 'inlineProperties', $inlinePropertiesObjectStorageMock);

		$this->subject->removeInlineProperty($inlineProperty);

	}
}
